=======================================
ZODB, a Python object-oriented database
=======================================

ZODB provides an object-oriented database for Python that provides a
high-degree of transparency.

- no separate language for database operations

- very little impact on your code to make objects persistent

- no database mapper that partially hides the database.

  Using an object-relational mapping **is not** like using an
  object-oriented database.

- almost no seam between code and database.

ZODB is an ACID Transactional database.

To learn more, visit: http://www.zodb.org

The github repository is: at https://github.com/zopefoundation/zodb

If you're interested in contributing to ZODB itself, see the
`developer notes
<https://github.com/zopefoundation/ZODB/blob/master/DEVELOPERS.rst>`_.
